==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/ro.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Spațiu de stocare indisponibil",
    "Storage invalid" : "Spațiu de stocare invalid",
    "Unknown error" : "Eroare necunoscută",
    "Unable to set upload directory." : "Imposibil de a seta directorul pentru încărcare.",
    "Invalid Token" : "Jeton Invalid",
    "No file was uploaded. Unknown error" : "Niciun fișier nu a fost încărcat. Eroare necunoscută",
    "There is no error, the file uploaded with success" : "Nu a apărut nici o eroare, fișierul a fost încărcat cu succes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The uploaded file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat nici un fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Failed to write to disk" : "Eroare la scrierea pe disc",
    "Not enough storage available" : "Nu este disponibil suficient spațiu",
    "The target folder has been moved or deleted." : "Dosarul țintă a fost mutat sau șters.",
    "Upload failed. Could not find uploaded file" : "Încărcare eșuată. Nu se poate găsi fișierul încărcat",
    "Upload failed. Could not get file info." : "Încărcare eșuată. Nu se pot obține informații despre fișier.",
    "Invalid directory." : "Dosar nevalid.",
    "Files" : "Fișiere",
    "All files" : "Toate fișierele.",
    "Favorites" : "Favorite",
    "Home" : "Acasă",
    "Close" : "Închide",
    "Upload cancelled." : "Încărcare anulată.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
    "Total file size {size1} exceeds upload limit {size2}" : "Mărimea fișierului este {size1} ce depășește limita de încărcare de {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
    "Could not get result from server." : "Nu se poate obține rezultatul de la server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fișierul este în curs de încărcare. Părăsirea paginii va întrerupe încărcarea.",
    "Actions" : "Acțiuni",
    "Download" : "Descarcă",
    "Rename" : "Redenumește",
    "Delete" : "Șterge",
    "Disconnect storage" : "Deconectează stocarea",
    "Unshare" : "Nu mai partaja",
    "Details" : "Detalii",
    "Select" : "Alege",
    "Pending" : "În așteptare",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "_%n file_::_%n files_" : ["%n fișier","%n fișiere","%n fișiere"],
    "{dirs} and {files}" : "{dirs} și {files}",
    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
    "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
    "New" : "Nou",
    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
    "File name cannot be empty." : "Numele fișierului nu poate rămâne gol.",
    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Spațiul de stocare este aproape plin ({usedSpacePercent}%)",
    "Favorite" : "Favorit",
    "Folder" : "Dosar",
    "New folder" : "Un nou dosar",
    "Upload" : "Încărcă",
    "A new file or folder has been <strong>created</strong>" : "Un nou fișier sau dosar a fost <strong>creat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un nou fișier sau dosar a fost <strong>modificat</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un nou fișier sau dosar a fost <strong>șters</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fișier sau dosar a fost <strong>restaurat</strong>",
    "You created %1$s" : "Ai creat %1$s",
    "%2$s created %1$s" : "%2$s a creat %1$s",
    "%1$s was created in a public folder" : "%1$s a fost creat în dosarul public",
    "You changed %1$s" : "Ai schimbat %1$s",
    "%2$s changed %1$s" : "%2$s a schimbat %1$s",
    "You deleted %1$s" : "Ai şters %1$s",
    "%2$s deleted %1$s" : "%2$s a șters %1$s",
    "You restored %1$s" : "Ai restaurat %1$s",
    "%2$s restored %1$s" : "%2$s a restaurat %1$s",
    "Upload (max. %s)" : "Încarcă (max. %s)",
    "File handling" : "Manipulare fișiere",
    "Maximum upload size" : "Dimensiune maximă admisă la încărcare",
    "max. possible: " : "max. posibil:",
    "Save" : "Salvează",
    "Settings" : "Setări",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Folosește această adresă <a href=\"%s\" target=\"_blank\">pentru acces la fișierele tale folosind WebDAV</a>",
    "Cancel upload" : "Anulează încărcarea",
    "Select all" : "Selectează tot",
    "Upload too large" : "Fișierul încărcat este prea mare",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
    "Text file" : "Fișier text",
    "You changed %1$s" : "Ai schimbat %1$s",
    "You created %1$s" : "Ai creat %1$s",
    "You deleted %1$s" : "Ai şters %1$s",
    "You restored %1$s" : "Ai restaurat %1$s"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/ro.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Spațiu de stocare indisponibil",
    "Storage invalid" : "Spațiu de stocare invalid",
    "Unknown error" : "Eroare necunoscută",
    "Unable to set upload directory." : "Imposibil de a seta directorul pentru încărcare.",
    "Invalid Token" : "Jeton Invalid",
    "No file was uploaded. Unknown error" : "Niciun fișier nu a fost încărcat. Eroare necunoscută",
    "There is no error, the file uploaded with success" : "Nu a apărut nici o eroare, fișierul a fost încărcat cu succes",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The uploaded file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Failed to write to disk" : "Eroare la scrierea pe disc",
    "Not enough storage available" : "Nu este disponibil suficient spațiu pe disc",
    "The target folder has been moved or deleted." : "Dosarul țintă a fost mutat sau șters.",
    "Upload failed. Could not find uploaded file" : "Încărcare eșuată. Nu se poate găsi fișierul încărcat",
    "Upload failed. Could not get file info." : "Încărcare eșuată. Nu se pot obține informații despre fișier.",
    "Invalid directory." : "Dosar invalid.",
    "Files" : "Fișiere",
    "All files" : "Toate fișierele.",
    "Home" : "Acasă",
    "Close" : "Închide",
    "Favorites" : "Favorite",
    "Upload cancelled." : "Încărcare anulată.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
    "Total file size {size1} exceeds upload limit {size2}" : "Mărimea fișierului este {size1} ce depășește limita de încărcare de {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
    "Could not get result from server." : "Nu se poate obține rezultatul de la server.",
    "Uploading..." : "Încărcare",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fișierul este în curs de încărcare. Părăsirea paginii va întrerupe încărcarea.",
    "Actions" : "Acțiuni",
    "Download" : "Descarcă",
    "Rename" : "Redenumește",
    "Delete" : "Șterge",
    "Disconnect storage" : "Deconectează stocarea",
    "Unshare" : "Nu mai partaja",
    "Details" : "Detalii",
    "Select" : "Alege",
    "Pending" : "În așteptare",
    "Unable to determine date" : "Nu s-a putut determina data",
    "This operation is forbidden" : "Operațiunea este interzisă",
    "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
    "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not move \"{file}\"" : "Nu s-a putut muta fișierul \"{file}\"",
    "{newName} already exists" : "{newName} există deja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nu s-a putut redenumi \"{fileName}\", fișierul nu mai există",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{targetName}\" este deja folosit în directorul \"{dir}\". Alege un nume diferit.",
    "Could not rename \"{fileName}\"" : "Nu s-a putut redenumi \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nu s-a putut crea fișierul \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nu s-a putut crea fișierul \"{file}\" deoarece există deja unul cu același nume",
    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Nu s-a putut crea directorul \"{dir}\" deoarece există deja unul cu același nume",
    "Error deleting file \"{fileName}\"." : "Eroare la ștergerea fișierului \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Niciun element din acest director nu se potrivește cu '{filter}'",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "_%n file_::_%n files_" : ["%n fișier","%n fișiere","%n fișiere"],
    "{dirs} and {files}" : "{dirs} și {files}",
    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
    "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
    "New" : "Nou",
    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
    "File name cannot be empty." : "Numele fișierului nu poate rămâne gol.",
    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Spațiul de stocare este aproape plin ({usedSpacePercent}%)",
    "Path" : "Cale",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
    "Favorited" : "Adăugate la favorite",
    "Favorite" : "Favorit",
    "Local link" : "Legătură locală",
    "Folder" : "Dosar",
    "New folder" : "Un nou dosar",
    "{newname} already exists" : "{newname} există deja",
    "Upload" : "Încărcă",
    "An error occurred while trying to update the tags" : "A apărut o eroare în timpul actualizării etichetelor",
    "A new file or folder has been <strong>created</strong>" : "Un nou fișier sau dosar a fost <strong>creat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un nou fișier sau dosar a fost <strong>modificat</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un nou fișier sau dosar a fost <strong>șters</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fișier sau dosar a fost <strong>restaurat</strong>",
    "You created %1$s" : "Ai creat %1$s",
    "%2$s created %1$s" : "%2$s a creat %1$s",
    "%1$s was created in a public folder" : "%1$s a fost creat în dosarul public",
    "You changed %1$s" : "Ai schimbat %1$s",
    "%2$s changed %1$s" : "%2$s a schimbat %1$s",
    "You deleted %1$s" : "Ai şters %1$s",
    "%2$s deleted %1$s" : "%2$s a șters %1$s",
    "You restored %1$s" : "Ai restaurat %1$s",
    "%2$s restored %1$s" : "%2$s a restaurat %1$s",
    "Changed by %2$s" : "Modificat de %2$s",
    "Deleted by %2$s" : "Șters de %2$s",
    "Restored by %2$s" : "Restaurat de %2$s",
    "Upload (max. %s)" : "Încarcă (max. %s)",
    "File handling" : "Manipulare fișiere",
    "Maximum upload size" : "Dimensiune maximă admisă la încărcare",
    "max. possible: " : "max. posibil:",
    "Save" : "Salvează",
    "Missing permissions to edit from here." : "Nu ai permisiuni pentru a edita aici.",
    "Settings" : "Setări",
    "Show hidden files" : "Arată fișierele ascunse",
    "WebDAV" : "WebDAV",
    "No files in here" : "Niciun fișier aici",
    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Select all" : "Selectează tot",
    "Upload too large" : "Fișierul încărcat este prea mare",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
    "No favorites" : "Fără favorite",
    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
    "Text file" : "Fișier text",
    "New text file.txt" : "New text file.txt"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
